<?php
/**
 * ChatDataWebhook Module
 *
 * This module sends webhooks for product create, update, and delete events.
 *
 * @author    Chat Data
 * @copyright Copyright (c) Chat Data
 * @license   Commercial License
 *
 * @see      https://www.chat-data.com/
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class ChatDataWebhook extends Module
{
    public function __construct()
    {
        $this->name = 'chatdatawebhook';
        $this->tab = 'administration';
        $this->version = '1.0.0';
        $this->author = 'Chat Data';
        $this->need_instance = 0;
        $this->bootstrap = true;
        $this->ps_versions_compliancy = ['min' => '1.7.0.0', 'max' => _PS_VERSION_];

        parent::__construct();

        $this->displayName = $this->l('Chat Data Webhook');
        $this->description = $this->l('Sends webhooks when products are created, updated, or deleted to Chat Data platform.');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    /**
     * Installation method.
     * Registers hooks.
     *
     * @return bool
     */
    public function install()
    {
        if (!parent::install()
            || !$this->registerHook('actionObjectProductAddAfter')
            || !$this->registerHook('actionObjectProductUpdateAfter')
            || !$this->registerHook('actionObjectProductDeleteAfter')
            || !Configuration::updateValue('CHATDATAWEBHOOK_URL', '')
            || !Configuration::updateValue('CHATDATAWEBHOOK_SECRET', $this->generateSecret())) {
            return false;
        }

        return true;
    }

    /**
     * Uninstallation method.
     * Unregisters hooks.
     *
     * @return bool
     */
    public function uninstall()
    {
        if (!parent::uninstall()
            || !Configuration::deleteByName('CHATDATAWEBHOOK_URL')
            || !Configuration::deleteByName('CHATDATAWEBHOOK_SECRET')) {
            return false;
        }

        return true;
    }

    /**
     * Generate a random secret key for webhook verification
     */
    private function generateSecret($length = 32)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; ++$i) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }

        return $randomString;
    }

    /**
     * Hook called after a new product is added.
     *
     * @param array $params parameters passed to the hook, including the new product object
     */
    public function hookActionObjectProductAddAfter($params)
    {
        $product = $params['object'];
        if ($product instanceof Product && (int) $product->active === 1) {
            $this->sendWebhook('product.created', $product);
        }
    }

    /**
     * Hook called after a product is updated.
     *
     * @param array $params parameters passed to the hook, including the updated product object
     */
    public function hookActionObjectProductUpdateAfter($params)
    {
        $product = $params['object'];
        if ($product instanceof Product) {
            $this->sendWebhook('product.updated', $product);
        }
    }

    /**
     * Hook called after a product is deleted.
     *
     * @param array $params parameters passed to the hook, including the deleted product object
     */
    public function hookActionObjectProductDeleteAfter($params)
    {
        $product = $params['object'];
        if ($product instanceof Product) {
            $this->sendWebhook('product.deleted', $product);
        } elseif (isset($params['id_product'])) {
            // Handle case where only the product ID is available
            $this->sendWebhook('product.deleted', ['id' => (int) $params['id_product']]);
        } elseif (isset($params['id'])) {
            // Handle case where only the ID is available
            $this->sendWebhook('product.deleted', ['id' => (int) $params['id']]);
        }
    }

    /**
     * Sends the webhook payload to the target URL.
     *
     * @param string $eventType The type of event (e.g., 'product.created').
     * @param mixed $data the data to send (Product object or an array with ID)
     */
    protected function sendWebhook($eventType, $data)
    {
        $targetUrl = Configuration::get('CHATDATAWEBHOOK_URL');
        $secret = Configuration::get('CHATDATAWEBHOOK_SECRET');

        if (empty($targetUrl)) {
            PrestaShopLogger::addLog('[ChatDataWebhook] Webhook Target URL is not configured.', 2, null, 'ChatDataWebhook', null, true);

            return; // Don't attempt to send if URL is not set
        }

        // Get default shop configurations for units and currency
        $defaultCurrencyId = (int) Configuration::get('PS_CURRENCY_DEFAULT');
        $weightUnit = Configuration::get('PS_WEIGHT_UNIT');
        $dimensionUnit = Configuration::get('PS_DIMENSION_UNIT');

        // Fallback to common defaults if configurations are not set
        if (empty($weightUnit)) {
            $weightUnit = 'kg';
        }
        if (empty($dimensionUnit)) {
            $dimensionUnit = 'cm';
        }

        $productDetails = [];
        // Initialize variables that might be used later
        $productOptionValues = [];
        $attributeGroups = [];
        $hasAttributes = false;
        $stock = [];

        if ($data instanceof Product) {
            $defaultLangId = (int) Configuration::get('PS_LANG_DEFAULT');
            $context = Context::getContext();
            $linkRewrite = '';

            if (is_array($data->link_rewrite) && isset($data->link_rewrite[$defaultLangId])) {
                $linkRewrite = $data->link_rewrite[$defaultLangId];
            } elseif (!is_array($data->link_rewrite)) {
                $linkRewrite = $data->link_rewrite;
            }

            // Get product name
            $productName = '';
            if (is_array($data->name) && isset($data->name[$defaultLangId])) {
                $productName = $data->name[$defaultLangId];
            } elseif (!is_array($data->name)) {
                $productName = $data->name;
            }

            // Get categories names
            $categoryIds = $data->getCategories();
            $categories = [];
            $categoryPaths = [];
            $defaultCategory = null;

            if (!empty($categoryIds)) {
                foreach ($categoryIds as $categoryId) {
                    try {
                        $category = new Category($categoryId, $defaultLangId);
                        if (Validate::isLoadedObject($category)) {
                            // Add the direct category name
                            $categories[] = $category->name;

                            // Check if this is the default category
                            if ((int) $categoryId === (int) $data->id_category_default) {
                                $defaultCategory = $category->name;
                            }

                            // Get full category path
                            $path = [];
                            $pathCategories = [];

                            if (method_exists($category, 'getParentsCategories')) {
                                // PrestaShop 1.7+
                                $pathCategories = array_reverse($category->getParentsCategories($defaultLangId));
                            } else {
                                // Manual implementation for older versions
                                $currentCat = $category;
                                while ($currentCat->id_parent != 0 && $currentCat->id_parent != $currentCat->id) {
                                    $parent = new Category($currentCat->id_parent, $defaultLangId);
                                    if (Validate::isLoadedObject($parent)) {
                                        $pathCategories[] = $parent;
                                    }
                                    $currentCat = $parent;
                                }
                                $pathCategories = array_reverse($pathCategories);
                                $pathCategories[] = $category; // Add the category itself
                            }

                            foreach ($pathCategories as $pathCategory) {
                                $path[] = $pathCategory->name;
                            }

                            if (!empty($path)) {
                                $categoryPaths[] = [
                                    'id' => $category->id,
                                    'name' => $category->name,
                                    'path' => implode(' > ', $path),
                                ];
                            }
                        }
                    } catch (Exception $e) {
                        PrestaShopLogger::addLog(
                            sprintf('[ChatDataWebhook] Error getting category info: %s', $e->getMessage()),
                            3, // Severity: 3 for error
                            null,
                            'ChatDataWebhook',
                            null,
                            true
                        );
                    }
                }
            }

            // If default category wasn't found in the associations, fetch it directly
            if (!$defaultCategory && (int) $data->id_category_default > 0) {
                try {
                    $defaultCat = new Category((int) $data->id_category_default, $defaultLangId);
                    if (Validate::isLoadedObject($defaultCat)) {
                        $defaultCategory = $defaultCat->name;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting default category info: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            // Get manufacturer name
            $manufacturerName = '';
            if ($data->id_manufacturer > 0) {
                $manufacturer = new Manufacturer($data->id_manufacturer);
                if (Validate::isLoadedObject($manufacturer)) {
                    $manufacturerName = $manufacturer->name;
                }
            }

            // Get specific prices
            $specificPrices = [];
            $currentSpecificPrice = null;
            $specificPricesList = SpecificPrice::getByProductId($data->id);
            $filteredSpecificPrices = []; // Initialize as empty array

            if (!empty($specificPricesList)) {
                // Filter specific prices to match JavaScript logic
                // Only include prices for all customers (id_customer=0, id_group=0, id_cart=0, id_currency=0, id_country=0)
                // and only currently active prices
                $filteredSpecificPrices = [];
                foreach ($specificPricesList as $sp) {
                    // Check if price is for all customers (matching JavaScript filter conditions)
                    $isForAllCustomers =
                        (string) $sp['id_customer'] === '0'
                        && (string) $sp['id_group'] === '0'
                        && (string) $sp['id_cart'] === '0'
                        && (string) $sp['id_currency'] === '0'
                        && (string) $sp['id_country'] === '0';

                    // Check if the specific price is currently active
                    $now = new DateTime();
                    $fromDate = $sp['from'] != '0000-00-00 00:00:00' ? new DateTime($sp['from']) : null;
                    $toDate = $sp['to'] != '0000-00-00 00:00:00' ? new DateTime($sp['to']) : null;
                    $isActive = (!$fromDate || $now >= $fromDate) && (!$toDate || $now <= $toDate);

                    if ($isForAllCustomers && $isActive) {
                        $filteredSpecificPrices[] = $sp;
                    }
                }

                // Process only the filtered specific prices
                foreach ($filteredSpecificPrices as $sp) {
                    $basePrice = (float) $data->price;
                    $finalPrice = $basePrice;

                    // Calculate final price based on reduction type
                    if ($sp['reduction_type'] == 'amount') {
                        // Fixed amount reduction
                        $finalPrice = $basePrice - (float) $sp['reduction'];
                    } elseif ($sp['reduction_type'] == 'percentage') {
                        // Percentage reduction
                        $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                    }

                    // Format the prices
                    $formattedBasePrice = Tools::displayPrice($basePrice, $defaultCurrencyId);
                    $formattedFinalPrice = Tools::displayPrice($finalPrice, $defaultCurrencyId);

                    // Format the reduction amount
                    $reductionDisplay = '';
                    if ($sp['reduction_type'] == 'amount') {
                        $reductionDisplay = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                    } else {
                        $reductionDisplay = (float) ($sp['reduction'] * 100) . '%';
                    }

                    // Since we already filtered for active prices, all prices here are active
                    // If active and for all combinations or default combination, set as current specific price
                    $defaultAttributeId = 0;
                    try {
                        if (method_exists($data, 'getDefaultIdProductAttribute')) {
                            $defaultAttributeId = $data->getDefaultIdProductAttribute();
                        }
                    } catch (Exception $e) {
                        PrestaShopLogger::addLog(
                            sprintf('[ChatDataWebhook] Error getting default product attribute: %s', $e->getMessage()),
                            3, // Severity: 3 for error
                            null,
                            'ChatDataWebhook',
                            null,
                            true
                        );
                    }

                    if ($sp['id_product_attribute'] == 0 || $sp['id_product_attribute'] == $defaultAttributeId) {
                        $currentSpecificPrice = [
                            'regular_price' => $formattedBasePrice,
                            'sale_price' => $formattedFinalPrice,
                            'discount' => $reductionDisplay,
                            'discount_type' => $sp['reduction_type'],
                            'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                            'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                        ];
                    }

                    $specificPrices[] = [
                        'id' => $sp['id_specific_price'],
                        'for_combination' => $sp['id_product_attribute'] > 0 ? $sp['id_product_attribute'] : 'All combinations',
                        'price' => $formattedFinalPrice,
                        'reduction' => $reductionDisplay,
                        'from' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : $sp['from'],
                        'to' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : $sp['to'],
                        'active' => true, // All filtered prices are active
                    ];
                }
            }

            // If no active specific price was found, use the regular price
            if ($currentSpecificPrice === null) {
                $currentSpecificPrice = Tools::displayPrice((float) $data->price, $defaultCurrencyId);
            }

            // Get product features
            $features = [];
            try {
                // First approach: Use built-in method (modern versions)
                $productFeatures = [];
                if (method_exists('Product', 'getFrontFeaturesStatic')) {
                    $productFeatures = Product::getFrontFeaturesStatic($defaultLangId, $data->id);
                } else {
                    // Second approach: Query the database directly (older versions)
                    $result = Db::getInstance()->executeS('
                        SELECT pf.id_feature, pf.position, pfl.name AS feature_name, pfv.id_feature_value, pfvl.value
                        FROM ' . _DB_PREFIX_ . 'feature_product fp
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature pf ON (pf.id_feature = fp.id_feature)
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_lang pfl ON (pfl.id_feature = pf.id_feature AND pfl.id_lang = ' . (int) $defaultLangId . ')
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_value pfv ON (pfv.id_feature_value = fp.id_feature_value)
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_value_lang pfvl ON (pfvl.id_feature_value = pfv.id_feature_value AND pfvl.id_lang = ' . (int) $defaultLangId . ')
                        WHERE fp.id_product = ' . (int) $data->id . '
                        ORDER BY pf.position ASC
                    ');

                    if ($result) {
                        foreach ($result as $row) {
                            $productFeatures[] = [
                                'name' => $row['feature_name'],
                                'value' => $row['value'],
                                'id_feature' => $row['id_feature'],
                                'id_feature_value' => $row['id_feature_value'],
                            ];
                        }
                    }
                }

                // Third approach: Use Feature and FeatureValue classes (better details)
                if (empty($productFeatures)) {
                    // Get feature products links
                    $featureProducts = Db::getInstance()->executeS('
                        SELECT * FROM ' . _DB_PREFIX_ . 'feature_product
                        WHERE id_product = ' . (int) $data->id
                    );

                    if ($featureProducts) {
                        foreach ($featureProducts as $featureProduct) {
                            try {
                                $featureId = $featureProduct['id_feature'];
                                $featureValueId = $featureProduct['id_feature_value'];

                                // Get feature name
                                $feature = new Feature($featureId, $defaultLangId);
                                $featureName = Validate::isLoadedObject($feature) ? $feature->name : 'Feature ' . $featureId;

                                // Get feature value
                                $featureValue = new FeatureValue($featureValueId, $defaultLangId);
                                $value = Validate::isLoadedObject($featureValue) ? $featureValue->value : 'Value ' . $featureValueId;

                                $productFeatures[] = [
                                    'name' => $featureName,
                                    'value' => $value,
                                    'id_feature' => $featureId,
                                    'id_feature_value' => $featureValueId,
                                ];
                            } catch (Exception $e) {
                                PrestaShopLogger::addLog(
                                    sprintf('[ChatDataWebhook] Error getting feature details: %s', $e->getMessage()),
                                    3, // Severity: 3 for error
                                    null,
                                    'ChatDataWebhook',
                                    null,
                                    true
                                );
                            }
                        }
                    }
                }

                foreach ($productFeatures as $feature) {
                    $featureDetail = [
                        'name' => $feature['name'],
                        'value' => $feature['value'],
                    ];

                    // Add IDs if available
                    if (isset($feature['id_feature'])) {
                        $featureDetail['id_feature'] = (int) $feature['id_feature'];
                    }
                    if (isset($feature['id_feature_value'])) {
                        $featureDetail['id_feature_value'] = (int) $feature['id_feature_value'];
                    }

                    $features[] = $featureDetail;
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product features: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get product accessories
            $accessories = [];
            try {
                // First approach: Use Product method if available
                if (method_exists($data, 'getAccessories')) {
                    $productAccessories = $data->getAccessories($defaultLangId);
                    if (!empty($productAccessories)) {
                        foreach ($productAccessories as $accessory) {
                            $accessories[] = [
                                'id' => (int) $accessory['id_product'],
                                'name' => $accessory['name'] ?? ('Accessory ' . $accessory['id_product']),
                            ];
                        }
                    }
                } else {
                    // Second approach: Query database directly for older versions
                    $accessoryResult = Db::getInstance()->executeS('
                        SELECT a.id_product_2 as id_product, pl.name
                        FROM ' . _DB_PREFIX_ . 'accessory a
                        LEFT JOIN ' . _DB_PREFIX_ . 'product_lang pl ON (a.id_product_2 = pl.id_product AND pl.id_lang = ' . (int) $defaultLangId . ')
                        WHERE a.id_product_1 = ' . (int) $data->id
                    );

                    if ($accessoryResult) {
                        foreach ($accessoryResult as $accessory) {
                            $accessories[] = [
                                'id' => (int) $accessory['id_product'],
                                'name' => $accessory['name'] ?? ('Accessory ' . $accessory['id_product']),
                            ];
                        }
                    }
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product accessories: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get product tags
            $tags = [];
            try {
                // Get product tags from Tag class if available
                if (class_exists('Tag')) {
                    if (method_exists('Tag', 'getProductTags')) {
                        // Modern PrestaShop approach
                        $productTags = Tag::getProductTags($data->id);
                        if (isset($productTags[$defaultLangId]) && is_array($productTags[$defaultLangId])) {
                            $tags = $productTags[$defaultLangId];
                        }
                    } else {
                        // Alternative approach using direct DB query
                        $tagsResult = Db::getInstance()->executeS('
                            SELECT t.name
                            FROM ' . _DB_PREFIX_ . 'tag t
                            LEFT JOIN ' . _DB_PREFIX_ . 'product_tag pt ON (pt.id_tag = t.id_tag)
                            WHERE pt.id_product = ' . (int) $data->id . '
                            AND t.id_lang = ' . (int) $defaultLangId
                        );

                        if ($tagsResult && is_array($tagsResult)) {
                            foreach ($tagsResult as $tag) {
                                $tags[] = $tag['name'];
                            }
                        }
                    }
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product tags: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get combinations
            $combinationsList = [];
            try {
                $combinationsList = $data->getAttributeCombinations($defaultLangId);
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product combinations: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get all combination details through DB for maximum data
            $combinationsDetails = [];
            try {
                $combinationsDetailsQuery = '
                    SELECT 
                        pa.*, 
                        sa.quantity,
                        GROUP_CONCAT(pac.id_attribute) as attributes
                    FROM ' . _DB_PREFIX_ . 'product_attribute pa
                    LEFT JOIN ' . _DB_PREFIX_ . 'stock_available sa ON (pa.id_product_attribute = sa.id_product_attribute AND sa.id_product = pa.id_product)
                    LEFT JOIN ' . _DB_PREFIX_ . 'product_attribute_combination pac ON (pa.id_product_attribute = pac.id_product_attribute)
                    WHERE pa.id_product = ' . (int) $data->id . '
                    GROUP BY pa.id_product_attribute
                ';
                $combinationsDetailsResult = Db::getInstance()->executeS($combinationsDetailsQuery);
                if ($combinationsDetailsResult) {
                    foreach ($combinationsDetailsResult as $comboDetails) {
                        $combinationsDetails[$comboDetails['id_product_attribute']] = $comboDetails;
                    }
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting combinations details: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            $processedCombinations = [];

            foreach ($combinationsList as $combo) {
                $idCombination = $combo['id_product_attribute'];

                if (!isset($processedCombinations[$idCombination])) {
                    // Create base combination data
                    $basePrice = (float) $data->price + (float) $combo['price'];

                    $detailedCombo = [
                        'id' => $idCombination,
                        'reference' => !empty($combo['reference']) ? $combo['reference'] : $data->reference,
                        'quantity' => isset($combinationsDetails[$idCombination]['quantity']) ? (int) $combinationsDetails[$idCombination]['quantity'] : StockAvailable::getQuantityAvailableByProduct($data->id, $idCombination),
                        'options' => [],
                    ];

                    // Add EAN13, ISBN, UPC if available in combinations detail
                    if (isset($combinationsDetails[$idCombination])) {
                        if (!empty($combinationsDetails[$idCombination]['ean13'])) {
                            $detailedCombo['ean13'] = $combinationsDetails[$idCombination]['ean13'];
                        }
                        if (!empty($combinationsDetails[$idCombination]['isbn'])) {
                            $detailedCombo['isbn'] = $combinationsDetails[$idCombination]['isbn'];
                        }
                        if (!empty($combinationsDetails[$idCombination]['upc'])) {
                            $detailedCombo['upc'] = $combinationsDetails[$idCombination]['upc'];
                        }
                        if (!empty($combinationsDetails[$idCombination]['mpn'])) {
                            $detailedCombo['mpn'] = $combinationsDetails[$idCombination]['mpn'];
                        }

                        // Add weight
                        $combinationWeight = (float) $combinationsDetails[$idCombination]['weight'];
                        if ($combinationWeight != 0) {
                            $totalWeight = $combinationWeight + (float) $data->weight;
                            $detailedCombo['weight'] = $totalWeight . ' ' . $weightUnit;
                        }
                    }

                    // Check for specific prices for this combination following JavaScript logic
                    $combinationSpecificPrice = null;
                    $applicableSpecificPrices = [];

                    // Filter specific prices that apply to this combination (id_product_attribute = 0 or matches combination ID)
                    foreach ($filteredSpecificPrices as $sp) {
                        if ($sp['id_product_attribute'] == '0' || (string) $sp['id_product_attribute'] === (string) $idCombination) {
                            $applicableSpecificPrices[] = $sp;
                        }
                    }

                    if (!empty($applicableSpecificPrices)) {
                        // Sort by date to get the most recent applicable price (like JavaScript)
                        usort($applicableSpecificPrices, function ($a, $b) {
                            $dateA = ($a['from'] !== '0000-00-00 00:00:00') ? strtotime($a['from']) : 0;
                            $dateB = ($b['from'] !== '0000-00-00 00:00:00') ? strtotime($b['from']) : 0;

                            return $dateB - $dateA; // Sort descending (most recent first)
                        });

                        $sp = $applicableSpecificPrices[0]; // Get the most recent
                        $finalPrice = $basePrice;

                        // Calculate final price based on reduction type
                        if ($sp['reduction_type'] == 'amount') {
                            $finalPrice = $basePrice - (float) $sp['reduction'];
                        } elseif ($sp['reduction_type'] == 'percentage') {
                            $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                        }

                        // Format discount amount
                        $discountAmount = '';
                        if ($sp['reduction_type'] == 'amount') {
                            $discountAmount = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                        } else {
                            $discountAmount = (float) ($sp['reduction'] * 100) . '%';
                        }

                        $combinationSpecificPrice = [
                            'regular_price_before_tax_shipping' => Tools::displayPrice($basePrice, $defaultCurrencyId),
                            'sale_price_before_tax_shipping' => Tools::displayPrice($finalPrice, $defaultCurrencyId),
                            'discount_type' => $sp['reduction_type'],
                            'discount_amount' => $discountAmount,
                            'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                            'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                        ];
                    }

                    // Add price field based on special price availability
                    if (!$combinationSpecificPrice) {
                        $detailedCombo['price_before_tax_shipping'] = Tools::displayPrice($basePrice, $defaultCurrencyId);
                    } else {
                        $detailedCombo['special_price'] = $combinationSpecificPrice;
                    }

                    $processedCombinations[$idCombination] = $detailedCombo;
                }

                // Add this attribute to the combination's options
                $attributeId = (int) $combo['id_attribute'];

                // Find detailed option from product_option_values
                $foundOption = null;
                foreach ($productOptionValues as $optionValue) {
                    if ($optionValue['id'] === $attributeId) {
                        $foundOption = $optionValue;
                        break;
                    }
                }

                // If not found, create a basic option
                if (!$foundOption) {
                    $foundOption = [
                        'id' => $attributeId,
                        'name' => $combo['attribute_name'] ?? ('Option ' . $attributeId),
                    ];
                }

                // Add to combination options (if not already present)
                $optionAlreadyAdded = false;
                foreach ($processedCombinations[$idCombination]['options'] as $existingOption) {
                    if ($existingOption['id'] === $foundOption['id']) {
                        $optionAlreadyAdded = true;
                        break;
                    }
                }

                if (!$optionAlreadyAdded) {
                    $processedCombinations[$idCombination]['options'][] = $foundOption;
                }
            }

            $combinations = array_values($processedCombinations);

            // Get stock
            $stock = [];
            if (!empty($combinations)) {
                // If product has combinations, only include combination stocks (skip main product stock)
                foreach ($combinations as $combination) {
                    $comboStock = StockAvailable::getQuantityAvailableByProduct($data->id, $combination['id']);
                    $variantInfo = [
                        'id' => (string) $combination['id'],
                        'reference' => $combination['reference'],
                        'options' => $combination['options'],
                    ];

                    $stock[] = [
                        'quantity' => (string) $comboStock,
                        'variant' => $variantInfo,
                    ];
                }
            } else {
                // For simple products without combinations, keep single product stock
                $mainStock = StockAvailable::getQuantityAvailableByProduct($data->id);
                $stock[] = [
                    'quantity' => (string) $mainStock,
                    'variant' => 'Main product',
                ];
            }

            // Calculate total quantity as sum of all stocks
            $totalQuantity = 0;
            foreach ($stock as $stockItem) {
                $totalQuantity += (int) $stockItem['quantity'];
            }

            // Get product images
            $images = [];
            $productImages = $data->getImages($defaultLangId);
            if (!empty($productImages)) {
                foreach ($productImages as $image) {
                    $imageUrl = $context->link->getImageLink($linkRewrite, $data->id . '-' . $image['id_image']);
                    $images[] = [
                        'src' => $imageUrl,
                        'alt' => $productName,
                    ];
                }
            }

            // Get short and full description
            $shortDescription = '';
            if (is_array($data->description_short) && isset($data->description_short[$defaultLangId])) {
                $shortDescription = $data->description_short[$defaultLangId];
            } elseif (!is_array($data->description_short)) {
                $shortDescription = $data->description_short;
            }

            $fullDescription = '';
            if (is_array($data->description) && isset($data->description[$defaultLangId])) {
                $fullDescription = $data->description[$defaultLangId];
            } elseif (!is_array($data->description)) {
                $fullDescription = $data->description;
            }

            // Create detailed product info
            $productDetails = [
                'id' => $data->id,
                'title' => $productName,
            ];

            // Only add non-empty fields
            if (!empty($data->reference)) {
                $productDetails['reference'] = $data->reference;
            }

            if (!empty($linkRewrite)) {
                $productDetails['link'] = $context->link->getProductLink($data->id, $linkRewrite, null, null, $defaultLangId);
            }

            $productDetails['status'] = (bool) $data->active ? 'active' : 'inactive';

            if (!empty($manufacturerName)) {
                $productDetails['manufacturer'] = $manufacturerName;
            }

            if ($data->weight > 0) {
                $productDetails['weight'] = $data->weight . ' ' . $weightUnit;
            }

            // Add dimensions if any dimension exists
            if ((float) $data->width > 0 || (float) $data->height > 0 || (float) $data->depth > 0) {
                $productDetails['dimensions'] = [
                    'width' => (float) $data->width > 0 ? $data->width . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                    'height' => (float) $data->height > 0 ? $data->height . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                    'depth' => (float) $data->depth > 0 ? $data->depth . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                ];
            }

            if (!empty($data->condition)) {
                $productDetails['condition'] = $data->condition;
            }

            $productDetails['quantity'] = $totalQuantity;

            // Add unit pricing information if it exists
            if (!empty($data->unity)) {
                $unitPricing = [
                    'unit' => $data->unity,
                ];

                // Add unit price if greater than 0
                if ((float) $data->unit_price > 0) {
                    $unitPricing['unit_price'] = Tools::displayPrice((float) $data->unit_price, $defaultCurrencyId);
                }

                // Add ratio if it exists
                if (!empty($data->unit_price_ratio)) {
                    $unitPricing['ratio'] = (string) $data->unit_price_ratio;
                }

                $productDetails['unit_pricing'] = $unitPricing;
            }

            // Add shipping information if additional cost exists
            if ((float) $data->additional_shipping_cost > 0) {
                $productDetails['additional_shipping_cost'] = Tools::displayPrice((float) $data->additional_shipping_cost, $defaultCurrencyId);
            }

            // Add product identifiers if they exist and aren't empty
            if (!empty($data->ean13)) {
                $productDetails['ean13'] = $data->ean13;
            }

            if (!empty($data->isbn)) {
                $productDetails['isbn'] = $data->isbn;
            }

            if (!empty($data->upc)) {
                $productDetails['upc'] = $data->upc;
            }

            if (!empty($data->mpn)) {
                $productDetails['mpn'] = $data->mpn;
            }

            if (!empty($categories)) {
                $productDetails['categories'] = $categories;
            }

            if (!empty($categoryPaths)) {
                $productDetails['category_paths'] = $categoryPaths;
            }

            // Add default category if available
            if (!empty($defaultCategory)) {
                $productDetails['default_category'] = $defaultCategory;
            }

            if (!empty($features)) {
                $productDetails['features'] = $features;
            }

            if (!empty($accessories)) {
                $productDetails['accessories'] = $accessories;
            }

            // Only add attribute groups if they contain data
            if (is_array($attributeGroups) && count($attributeGroups) > 0) {
                $productDetails['options'] = $attributeGroups;
            }

            // Only add product option values if they contain data
            if (is_array($productOptionValues) && count($productOptionValues) > 0) {
                $productDetails['product_option_values'] = $productOptionValues;
            }

            if (!empty($combinations)) {
                $productDetails['combinations'] = $combinations;
            }

            // Add stock details (combinations stocks if available, or main product stock)
            if (is_array($stock) && count($stock) > 0) {
                $productDetails['stock'] = $stock;
            }

            if (!empty($data->date_add)) {
                $productDetails['date_add'] = $data->date_add;
            }

            if (!empty($data->date_upd)) {
                $productDetails['date_upd'] = $data->date_upd;
            }

            if ((int) $data->minimal_quantity > 1) {
                $productDetails['minimal_quantity'] = (string) $data->minimal_quantity;
            }

            $productDetails['type'] = $hasAttributes ? 'combinations' : 'simple';

            if (!empty($images)) {
                $productDetails['images'] = $images;
            }

            if (!empty($shortDescription)) {
                $productDetails['short_description'] = $shortDescription;
            }

            if (!empty($fullDescription)) {
                $productDetails['description'] = $fullDescription;
            }

            // Add meta fields if they exist and are non-empty
            $metaTitle = '';
            if (is_array($data->meta_title) && isset($data->meta_title[$defaultLangId])) {
                $metaTitle = $data->meta_title[$defaultLangId];
            } elseif (!is_array($data->meta_title)) {
                $metaTitle = $data->meta_title;
            }
            if (!empty($metaTitle)) {
                $productDetails['meta_title'] = $metaTitle;
            }

            $metaKeywords = '';
            if (is_array($data->meta_keywords) && isset($data->meta_keywords[$defaultLangId])) {
                $metaKeywords = $data->meta_keywords[$defaultLangId];
            } elseif (!is_array($data->meta_keywords)) {
                $metaKeywords = $data->meta_keywords;
            }
            if (!empty($metaKeywords)) {
                $productDetails['meta_keywords'] = $metaKeywords;
            }

            $metaDescription = '';
            if (is_array($data->meta_description) && isset($data->meta_description[$defaultLangId])) {
                $metaDescription = $data->meta_description[$defaultLangId];
            } elseif (!is_array($data->meta_description)) {
                $metaDescription = $data->meta_description;
            }
            if (!empty($metaDescription)) {
                $productDetails['meta_description'] = $metaDescription;
            }

            // Add delivery fields if they exist and are non-empty
            $deliveryInStock = '';
            if (is_array($data->delivery_in_stock) && isset($data->delivery_in_stock[$defaultLangId])) {
                $deliveryInStock = $data->delivery_in_stock[$defaultLangId];
            } elseif (!is_array($data->delivery_in_stock)) {
                $deliveryInStock = $data->delivery_in_stock;
            }
            if (!empty($deliveryInStock)) {
                $productDetails['delivery_in_stock'] = $deliveryInStock;
            }

            $deliveryOutStock = '';
            if (is_array($data->delivery_out_stock) && isset($data->delivery_out_stock[$defaultLangId])) {
                $deliveryOutStock = $data->delivery_out_stock[$defaultLangId];
            } elseif (!is_array($data->delivery_out_stock)) {
                $deliveryOutStock = $data->delivery_out_stock;
            }
            if (!empty($deliveryOutStock)) {
                $productDetails['delivery_out_stock'] = $deliveryOutStock;
            }

            $availableLater = '';
            if (is_array($data->available_later) && isset($data->available_later[$defaultLangId])) {
                $availableLater = $data->available_later[$defaultLangId];
            } elseif (!is_array($data->available_later)) {
                $availableLater = $data->available_later;
            }
            if (!empty($availableLater)) {
                $productDetails['available_later'] = $availableLater;
            }

            $availableNow = '';
            if (is_array($data->available_now) && isset($data->available_now[$defaultLangId])) {
                $availableNow = $data->available_now[$defaultLangId];
            } elseif (!is_array($data->available_now)) {
                $availableNow = $data->available_now;
            }
            if (!empty($availableNow)) {
                $productDetails['available_now'] = $availableNow;
            }

            // Set flags based on binary values (following JavaScript logic)
            if ($data->on_sale === '1') {
                $productDetails['on_sale'] = true;
            }
            if ($data->customizable === '1') {
                $productDetails['customizable'] = true;
            }
            if ($data->online_only === '1') {
                $productDetails['online_only'] = true;
            }
            if ($data->is_virtual === '1') {
                $productDetails['is_virtual'] = true;
            }
            if ($data->available_for_order === '1') {
                $productDetails['available_for_order'] = true;
            }
            if ($data->show_price === '1') {
                $productDetails['show_price'] = true;
            }

            // Add product type if available (PS 1.7.7+)
            if (method_exists($data, 'getProductType')) {
                try {
                    $productType = $data->getProductType();
                    if (!empty($productType)) {
                        $productDetails['product_type'] = $productType;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product type: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            if (!empty($tags)) {
                $productDetails['tags'] = $tags;
            }

            // Add pricing information for the main product
            if (!$hasAttributes) {
                // For simple products without combinations, apply the same pricing logic as combinations
                $basePrice = (float) $data->price;
                $mainProductSpecificPrice = null;

                // Filter specific prices that apply to the main product (id_product_attribute = 0)
                $applicableMainSpecificPrices = [];
                foreach ($filteredSpecificPrices as $sp) {
                    if ($sp['id_product_attribute'] == '0') {
                        $applicableMainSpecificPrices[] = $sp;
                    }
                }

                if (!empty($applicableMainSpecificPrices)) {
                    // Sort by date to get the most recent applicable price
                    usort($applicableMainSpecificPrices, function ($a, $b) {
                        $dateA = ($a['from'] !== '0000-00-00 00:00:00') ? strtotime($a['from']) : 0;
                        $dateB = ($b['from'] !== '0000-00-00 00:00:00') ? strtotime($b['from']) : 0;

                        return $dateB - $dateA; // Sort descending (most recent first)
                    });

                    $sp = $applicableMainSpecificPrices[0]; // Get the most recent
                    $finalPrice = $basePrice;

                    // Calculate final price based on reduction type
                    if ($sp['reduction_type'] == 'amount') {
                        $finalPrice = $basePrice - (float) $sp['reduction'];
                    } elseif ($sp['reduction_type'] == 'percentage') {
                        $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                    }

                    // Format discount amount
                    $discountAmount = '';
                    if ($sp['reduction_type'] == 'amount') {
                        $discountAmount = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                    } else {
                        $discountAmount = (float) ($sp['reduction'] * 100) . '%';
                    }

                    $mainProductSpecificPrice = [
                        'regular_price_before_tax_shipping' => Tools::displayPrice($basePrice, $defaultCurrencyId),
                        'sale_price_before_tax_shipping' => Tools::displayPrice($finalPrice, $defaultCurrencyId),
                        'discount_type' => $sp['reduction_type'],
                        'discount_amount' => $discountAmount,
                        'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                        'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                    ];
                }

                // Add price field based on special price availability
                if (!$mainProductSpecificPrice) {
                    $productDetails['price_before_tax_shipping'] = Tools::displayPrice($basePrice, $defaultCurrencyId);
                } else {
                    $productDetails['special_price'] = $mainProductSpecificPrice;
                }
            }

            // Add product type if available (PS 1.7.7+)
            if (method_exists($data, 'getProductType')) {
                try {
                    $productType = $data->getProductType();
                    if (!empty($productType)) {
                        $productDetails['product_type'] = $productType;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product type: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            if (!empty($tags)) {
                $productDetails['tags'] = $tags;
            }
        } elseif ($eventType === 'product.deleted' && is_array($data) && isset($data['id'])) {
            // For delete event with just ID
            $productDetails = ['id' => (int) $data['id']];
        } elseif ($eventType === 'product.deleted' && $data instanceof Product) {
            // For delete event with Product object
            $productDetails = ['id' => $data->id];
        }

        $jsonData = json_encode($productDetails);

        // Using cURL to send the POST request
        $ch = curl_init($targetUrl);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Content-Length: ' . strlen($jsonData),
            'X-PrestaShop-Webhook-Signature: ' . base64_encode(hash_hmac('sha256', $jsonData, $secret, true)),
            'X-PrestaShop-Webhook-Topic: ' . $eventType,
            'X-PrestaShop-Shop-Url: ' . _PS_BASE_URL_,
            'X-PrestaShop-Timestamp: ' . date('c'),
        ]);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10); // Timeout in seconds
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);

        $result = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $curlError = curl_error($ch);
        curl_close($ch);

        // Log the attempt
        if ($result === false || $httpCode >= 400) {
            PrestaShopLogger::addLog(
                sprintf('[ChatDataWebhook] Failed to send webhook. Event: %s, URL: %s, HTTP Code: %s, cURL Error: %s', $eventType, $targetUrl, $httpCode, $curlError),
                3, // Severity: 3 for error
                null,
                'ChatDataWebhook',
                null,
                true
            );
        } else {
            PrestaShopLogger::addLog(
                sprintf('[ChatDataWebhook] Webhook sent successfully. Event: %s, URL: %s, HTTP Code: %s', $eventType, $targetUrl, $httpCode),
                1, // Severity: 1 for informational
                null,
                'ChatDataWebhook',
                null,
                true
            );
        }

        if ($result === false) {
            return [
                'success' => false,
                'error' => $curlError,
                'http_code' => $httpCode,
            ];
        } elseif ($httpCode >= 400) {
            return [
                'success' => false,
                'error' => 'HTTP Error ' . $httpCode,
                'http_code' => $httpCode,
                'response' => $result,
            ];
        } else {
            return [
                'success' => true,
                'http_code' => $httpCode,
                'response' => $result,
            ];
        }
    }

    /**
     * Configuration page content
     */
    public function getContent()
    {
        $output = '';
        $test_result = null;

        // Process form submission
        if (Tools::isSubmit('submit' . $this->name)) {
            $webhookUrl = Tools::getValue('CHATDATAWEBHOOK_URL');

            // Validate webhook URL
            if (empty($webhookUrl) || !Validate::isUrl($webhookUrl)) {
                $output .= $this->displayError($this->l('Invalid webhook URL'));
            } else {
                Configuration::updateValue('CHATDATAWEBHOOK_URL', $webhookUrl);
                // Regenerate secret if requested
                if (Tools::getValue('regenerate_secret')) {
                    Configuration::updateValue('CHATDATAWEBHOOK_SECRET', $this->generateSecret());
                }
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }

        // Handle test webhook submission
        if (Tools::isSubmit('submitTestWebhook')) {
            $productId = (int) Tools::getValue('test_product_id');
            $eventType = Tools::getValue('test_event_type');

            if ($productId > 0) {
                // Load the product
                $product = new Product($productId);

                if (Validate::isLoadedObject($product)) {
                    // Send test webhook
                    $result = $this->sendTestWebhook($eventType, $product);

                    // Store result for display
                    $test_result = $result;
                } else {
                    $test_result = [
                        'success' => false,
                        'error' => $this->l('Product not found with ID: ') . $productId,
                    ];
                }
            } else {
                $test_result = [
                    'success' => false,
                    'error' => $this->l('Invalid product ID'),
                ];
            }
        }

        // Get the current values for the templates
        $webhook_secret = Configuration::get('CHATDATAWEBHOOK_SECRET');
        $webhook_url = Configuration::get('CHATDATAWEBHOOK_URL');

        // Assign common variables to all templates
        $this->context->smarty->assign([
            'webhook_secret' => $webhook_secret,
            'webhook_url' => $webhook_url,
            'base_url' => _PS_BASE_URL_,
            'current_secret_key' => $webhook_secret,
            'module_dir' => $this->_path,
            'module_name' => $this->name,
            'test_product_id' => Tools::getValue('test_product_id', ''),
            'test_event_type' => Tools::getValue('test_event_type', 'product.updated'),
            'webhook_test_result' => $test_result,
        ]);

        // Render the documentation templates
        $config_info = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/config_info.tpl');
        $webhook_events = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/webhook_events.tpl');
        $documentation_link = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/documentation_link.tpl');

        // Render the test form
        $test_form = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/test.tpl');

        // Return the configuration form and test form with documentation above the form
        return $output . $config_info . $webhook_events . $documentation_link . $this->renderForm() . $test_form;
    }

    /**
     * Renders the configuration form
     */
    protected function renderForm()
    {
        $fields_form = [
            'form' => [
                'legend' => [
                    'title' => $this->l('Webhook Settings'),
                    'icon' => 'icon-cogs',
                ],
                'input' => [
                    [
                        'type' => 'text',
                        'label' => $this->l('Webhook URL'),
                        'name' => 'CHATDATAWEBHOOK_URL',
                        'desc' => $this->l('Enter the URL where product update webhooks will be sent. Get your unique webhook URL from your Chat Data dashboard.'),
                        'size' => 50,
                        'required' => true,
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->l('Regenerate Secret Key'),
                        'name' => 'regenerate_secret',
                        'desc' => $this->l('Enable to generate a new secret key. Warning: This will invalidate previous webhook signatures.'),
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Yes'),
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('No'),
                            ],
                        ],
                    ],
                ],
                'submit' => [
                    'title' => $this->l('Save'),
                    'class' => 'btn btn-default pull-right',
                ],
            ],
        ];

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $lang = new Language((int) Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submit' . $this->name;
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->module = $this;

        $helper->tpl_vars = [
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        ];

        return $helper->generateForm([$fields_form]);
    }

    /**
     * Get config values for form
     */
    public function getConfigFieldsValues()
    {
        return [
            'CHATDATAWEBHOOK_URL' => Configuration::get('CHATDATAWEBHOOK_URL'),
            'regenerate_secret' => 0,
        ];
    }

    /**
     * Send a test webhook
     *
     * @param string $eventType Event type
     * @param Product $product Product to send
     *
     * @return array Result of the webhook call
     */
    protected function sendTestWebhook($eventType, $product)
    {
        $targetUrl = Configuration::get('CHATDATAWEBHOOK_URL');
        $secret = Configuration::get('CHATDATAWEBHOOK_SECRET');

        if (empty($targetUrl)) {
            return [
                'success' => false,
                'error' => $this->l('Webhook URL is not configured'),
            ];
        }

        // Check if trying to send product.created event for inactive product
        if ($eventType === 'product.created' && $product instanceof Product && (int) $product->active !== 1) {
            return [
                'success' => false,
                'error' => $this->l('Cannot send product.created event for inactive products. The product must have active status set to 1.'),
            ];
        }

        // Get default shop configurations for units and currency
        $defaultCurrencyId = (int) Configuration::get('PS_CURRENCY_DEFAULT');
        $weightUnit = Configuration::get('PS_WEIGHT_UNIT');
        $dimensionUnit = Configuration::get('PS_DIMENSION_UNIT');

        // Fallback to common defaults if configurations are not set
        if (empty($weightUnit)) {
            $weightUnit = 'kg';
        }
        if (empty($dimensionUnit)) {
            $dimensionUnit = 'cm';
        }

        $productDetails = [];
        // Initialize variables that might be used later
        $productOptionValues = [];
        $attributeGroups = [];
        $hasAttributes = false;
        $stock = [];

        if ($product instanceof Product) {
            $defaultLangId = (int) Configuration::get('PS_LANG_DEFAULT');
            $context = Context::getContext();
            $linkRewrite = '';

            if (is_array($product->link_rewrite) && isset($product->link_rewrite[$defaultLangId])) {
                $linkRewrite = $product->link_rewrite[$defaultLangId];
            } elseif (!is_array($product->link_rewrite)) {
                $linkRewrite = $product->link_rewrite;
            }

            // Get product name
            $productName = '';
            if (is_array($product->name) && isset($product->name[$defaultLangId])) {
                $productName = $product->name[$defaultLangId];
            } elseif (!is_array($product->name)) {
                $productName = $product->name;
            }

            // Get categories names
            $categoryIds = $product->getCategories();
            $categories = [];
            $categoryPaths = [];
            $defaultCategory = null;

            if (!empty($categoryIds)) {
                foreach ($categoryIds as $categoryId) {
                    try {
                        $category = new Category($categoryId, $defaultLangId);
                        if (Validate::isLoadedObject($category)) {
                            // Add the direct category name
                            $categories[] = $category->name;

                            // Check if this is the default category
                            if ((int) $categoryId === (int) $product->id_category_default) {
                                $defaultCategory = $category->name;
                            }

                            // Get full category path
                            $path = [];
                            $pathCategories = [];

                            if (method_exists($category, 'getParentsCategories')) {
                                // PrestaShop 1.7+
                                $pathCategories = array_reverse($category->getParentsCategories($defaultLangId));
                            } else {
                                // Manual implementation for older versions
                                $currentCat = $category;
                                while ($currentCat->id_parent != 0 && $currentCat->id_parent != $currentCat->id) {
                                    $parent = new Category($currentCat->id_parent, $defaultLangId);
                                    if (Validate::isLoadedObject($parent)) {
                                        $pathCategories[] = $parent;
                                    }
                                    $currentCat = $parent;
                                }
                                $pathCategories = array_reverse($pathCategories);
                                $pathCategories[] = $category; // Add the category itself
                            }

                            foreach ($pathCategories as $pathCategory) {
                                $path[] = $pathCategory->name;
                            }

                            if (!empty($path)) {
                                $categoryPaths[] = [
                                    'id' => $category->id,
                                    'name' => $category->name,
                                    'path' => implode(' > ', $path),
                                ];
                            }
                        }
                    } catch (Exception $e) {
                        PrestaShopLogger::addLog(
                            sprintf('[ChatDataWebhook] Error getting category info: %s', $e->getMessage()),
                            3, // Severity: 3 for error
                            null,
                            'ChatDataWebhook',
                            null,
                            true
                        );
                    }
                }
            }

            // If default category wasn't found in the associations, fetch it directly
            if (!$defaultCategory && (int) $product->id_category_default > 0) {
                try {
                    $defaultCat = new Category((int) $product->id_category_default, $defaultLangId);
                    if (Validate::isLoadedObject($defaultCat)) {
                        $defaultCategory = $defaultCat->name;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting default category info: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            // Get manufacturer name
            $manufacturerName = '';
            if ($product->id_manufacturer > 0) {
                $manufacturer = new Manufacturer($product->id_manufacturer);
                if (Validate::isLoadedObject($manufacturer)) {
                    $manufacturerName = $manufacturer->name;
                }
            }

            // Get specific prices
            $specificPrices = [];
            $currentSpecificPrice = null;
            $specificPricesList = SpecificPrice::getByProductId($product->id);
            $filteredSpecificPrices = []; // Initialize as empty array

            if (!empty($specificPricesList)) {
                // Filter specific prices to match JavaScript logic
                // Only include prices for all customers (id_customer=0, id_group=0, id_cart=0, id_currency=0, id_country=0)
                // and only currently active prices
                $filteredSpecificPrices = [];
                foreach ($specificPricesList as $sp) {
                    // Check if price is for all customers (matching JavaScript filter conditions)
                    $isForAllCustomers =
                        (string) $sp['id_customer'] === '0'
                        && (string) $sp['id_group'] === '0'
                        && (string) $sp['id_cart'] === '0'
                        && (string) $sp['id_currency'] === '0'
                        && (string) $sp['id_country'] === '0';

                    // Check if the specific price is currently active
                    $now = new DateTime();
                    $fromDate = $sp['from'] != '0000-00-00 00:00:00' ? new DateTime($sp['from']) : null;
                    $toDate = $sp['to'] != '0000-00-00 00:00:00' ? new DateTime($sp['to']) : null;
                    $isActive = (!$fromDate || $now >= $fromDate) && (!$toDate || $now <= $toDate);

                    if ($isForAllCustomers && $isActive) {
                        $filteredSpecificPrices[] = $sp;
                    }
                }

                // Process only the filtered specific prices
                foreach ($filteredSpecificPrices as $sp) {
                    $basePrice = (float) $product->price;
                    $finalPrice = $basePrice;

                    // Calculate final price based on reduction type
                    if ($sp['reduction_type'] == 'amount') {
                        // Fixed amount reduction
                        $finalPrice = $basePrice - (float) $sp['reduction'];
                    } elseif ($sp['reduction_type'] == 'percentage') {
                        // Percentage reduction
                        $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                    }

                    // Format the prices
                    $formattedBasePrice = Tools::displayPrice($basePrice, $defaultCurrencyId);
                    $formattedFinalPrice = Tools::displayPrice($finalPrice, $defaultCurrencyId);

                    // Format the reduction amount
                    $reductionDisplay = '';
                    if ($sp['reduction_type'] == 'amount') {
                        $reductionDisplay = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                    } else {
                        $reductionDisplay = (float) ($sp['reduction'] * 100) . '%';
                    }

                    // Since we already filtered for active prices, all prices here are active
                    // If active and for all combinations or default combination, set as current specific price
                    $defaultAttributeId = 0;
                    try {
                        if (method_exists($product, 'getDefaultIdProductAttribute')) {
                            $defaultAttributeId = $product->getDefaultIdProductAttribute();
                        }
                    } catch (Exception $e) {
                        PrestaShopLogger::addLog(
                            sprintf('[ChatDataWebhook] Error getting default product attribute: %s', $e->getMessage()),
                            3, // Severity: 3 for error
                            null,
                            'ChatDataWebhook',
                            null,
                            true
                        );
                    }

                    if ($sp['id_product_attribute'] == 0 || $sp['id_product_attribute'] == $defaultAttributeId) {
                        $currentSpecificPrice = [
                            'regular_price' => $formattedBasePrice,
                            'sale_price' => $formattedFinalPrice,
                            'discount' => $reductionDisplay,
                            'discount_type' => $sp['reduction_type'],
                            'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                            'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                        ];
                    }

                    $specificPrices[] = [
                        'id' => $sp['id_specific_price'],
                        'for_combination' => $sp['id_product_attribute'] > 0 ? $sp['id_product_attribute'] : 'All combinations',
                        'price' => $formattedFinalPrice,
                        'reduction' => $reductionDisplay,
                        'from' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : $sp['from'],
                        'to' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : $sp['to'],
                        'active' => true, // All filtered prices are active
                    ];
                }
            }

            // If no active specific price was found, use the regular price
            if ($currentSpecificPrice === null) {
                $currentSpecificPrice = Tools::displayPrice((float) $product->price, $defaultCurrencyId);
            }

            // Get product features
            $features = [];
            try {
                // First approach: Use built-in method (modern versions)
                $productFeatures = [];
                if (method_exists('Product', 'getFrontFeaturesStatic')) {
                    $productFeatures = Product::getFrontFeaturesStatic($defaultLangId, $product->id);
                } else {
                    // Second approach: Query the database directly (older versions)
                    $result = Db::getInstance()->executeS('
                        SELECT pf.id_feature, pf.position, pfl.name AS feature_name, pfv.id_feature_value, pfvl.value
                        FROM ' . _DB_PREFIX_ . 'feature_product fp
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature pf ON (pf.id_feature = fp.id_feature)
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_lang pfl ON (pfl.id_feature = pf.id_feature AND pfl.id_lang = ' . (int) $defaultLangId . ')
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_value pfv ON (pfv.id_feature_value = fp.id_feature_value)
                        LEFT JOIN ' . _DB_PREFIX_ . 'feature_value_lang pfvl ON (pfvl.id_feature_value = pfv.id_feature_value AND pfvl.id_lang = ' . (int) $defaultLangId . ')
                        WHERE fp.id_product = ' . (int) $product->id . '
                        ORDER BY pf.position ASC
                    ');

                    if ($result) {
                        foreach ($result as $row) {
                            $productFeatures[] = [
                                'name' => $row['feature_name'],
                                'value' => $row['value'],
                                'id_feature' => $row['id_feature'],
                                'id_feature_value' => $row['id_feature_value'],
                            ];
                        }
                    }
                }

                // Third approach: Use Feature and FeatureValue classes (better details)
                if (empty($productFeatures)) {
                    // Get feature products links
                    $featureProducts = Db::getInstance()->executeS('
                        SELECT * FROM ' . _DB_PREFIX_ . 'feature_product
                        WHERE id_product = ' . (int) $product->id
                    );

                    if ($featureProducts) {
                        foreach ($featureProducts as $featureProduct) {
                            try {
                                $featureId = $featureProduct['id_feature'];
                                $featureValueId = $featureProduct['id_feature_value'];

                                // Get feature name
                                $feature = new Feature($featureId, $defaultLangId);
                                $featureName = Validate::isLoadedObject($feature) ? $feature->name : 'Feature ' . $featureId;

                                // Get feature value
                                $featureValue = new FeatureValue($featureValueId, $defaultLangId);
                                $value = Validate::isLoadedObject($featureValue) ? $featureValue->value : 'Value ' . $featureValueId;

                                $productFeatures[] = [
                                    'name' => $featureName,
                                    'value' => $value,
                                    'id_feature' => $featureId,
                                    'id_feature_value' => $featureValueId,
                                ];
                            } catch (Exception $e) {
                                PrestaShopLogger::addLog(
                                    sprintf('[ChatDataWebhook] Error getting feature details: %s', $e->getMessage()),
                                    3, // Severity: 3 for error
                                    null,
                                    'ChatDataWebhook',
                                    null,
                                    true
                                );
                            }
                        }
                    }
                }

                foreach ($productFeatures as $feature) {
                    $featureDetail = [
                        'name' => $feature['name'],
                        'value' => $feature['value'],
                    ];

                    // Add IDs if available
                    if (isset($feature['id_feature'])) {
                        $featureDetail['id_feature'] = (int) $feature['id_feature'];
                    }
                    if (isset($feature['id_feature_value'])) {
                        $featureDetail['id_feature_value'] = (int) $feature['id_feature_value'];
                    }

                    $features[] = $featureDetail;
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product features: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get product accessories
            $accessories = [];
            try {
                // First approach: Use Product method if available
                if (method_exists($product, 'getAccessories')) {
                    $productAccessories = $product->getAccessories($defaultLangId);
                    if (!empty($productAccessories)) {
                        foreach ($productAccessories as $accessory) {
                            $accessories[] = [
                                'id' => (int) $accessory['id_product'],
                                'name' => $accessory['name'] ?? ('Accessory ' . $accessory['id_product']),
                            ];
                        }
                    }
                } else {
                    // Second approach: Query database directly for older versions
                    $accessoryResult = Db::getInstance()->executeS('
                        SELECT a.id_product_2 as id_product, pl.name
                        FROM ' . _DB_PREFIX_ . 'accessory a
                        LEFT JOIN ' . _DB_PREFIX_ . 'product_lang pl ON (a.id_product_2 = pl.id_product AND pl.id_lang = ' . (int) $defaultLangId . ')
                        WHERE a.id_product_1 = ' . (int) $product->id
                    );

                    if ($accessoryResult) {
                        foreach ($accessoryResult as $accessory) {
                            $accessories[] = [
                                'id' => (int) $accessory['id_product'],
                                'name' => $accessory['name'] ?? ('Accessory ' . $accessory['id_product']),
                            ];
                        }
                    }
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product accessories: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get product tags
            $tags = [];
            try {
                // Get product tags from Tag class if available
                if (class_exists('Tag')) {
                    if (method_exists('Tag', 'getProductTags')) {
                        // Modern PrestaShop approach
                        $productTags = Tag::getProductTags($product->id);
                        if (isset($productTags[$defaultLangId]) && is_array($productTags[$defaultLangId])) {
                            $tags = $productTags[$defaultLangId];
                        }
                    } else {
                        // Alternative approach using direct DB query
                        $tagsResult = Db::getInstance()->executeS('
                            SELECT t.name
                            FROM ' . _DB_PREFIX_ . 'tag t
                            LEFT JOIN ' . _DB_PREFIX_ . 'product_tag pt ON (pt.id_tag = t.id_tag)
                            WHERE pt.id_product = ' . (int) $product->id . '
                            AND t.id_lang = ' . (int) $defaultLangId
                        );

                        if ($tagsResult && is_array($tagsResult)) {
                            foreach ($tagsResult as $tag) {
                                $tags[] = $tag['name'];
                            }
                        }
                    }
                }
            } catch (Exception $e) {
                PrestaShopLogger::addLog(
                    sprintf('[ChatDataWebhook] Error getting product tags: %s', $e->getMessage()),
                    3, // Severity: 3 for error
                    null,
                    'ChatDataWebhook',
                    null,
                    true
                );
            }

            // Get combinations
            $combinations = [];
            $attributes = [];
            $attributeGroups = [];
            $productOptionValues = [];

            // Get attribute groups and values
            $hasAttributes = false;
            if (method_exists($product, 'hasAttributes')) {
                $hasAttributes = $product->hasAttributes();
            } else {
                // Fallback for older PrestaShop versions
                try {
                    $hasAttributes = (bool) Db::getInstance()->getValue('
                        SELECT COUNT(*)
                        FROM `' . _DB_PREFIX_ . 'product_attribute`
                        WHERE `id_product` = ' . (int) $product->id
                    );
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error checking product attributes: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            if ($hasAttributes) {
                try {
                    // Approach 1: Get attributes and values using direct DB access (most reliable)
                    $attributesQuery = '
                        SELECT pa.id_product_attribute, pa.id_product,
                              ag.id_attribute_group, ag.position AS group_position, agl.name AS group_name, agl.public_name AS group_public_name,
                              a.id_attribute, a.position, a.color, al.name AS attribute_name
                        FROM ' . _DB_PREFIX_ . 'product_attribute pa
                        LEFT JOIN ' . _DB_PREFIX_ . 'product_attribute_combination pac ON (pa.id_product_attribute = pac.id_product_attribute)
                        LEFT JOIN ' . _DB_PREFIX_ . 'attribute a ON (a.id_attribute = pac.id_attribute)
                        LEFT JOIN ' . _DB_PREFIX_ . 'attribute_group ag ON (ag.id_attribute_group = a.id_attribute_group)
                        LEFT JOIN ' . _DB_PREFIX_ . 'attribute_lang al ON (a.id_attribute = al.id_attribute AND al.id_lang = ' . (int) $defaultLangId . ')
                        LEFT JOIN ' . _DB_PREFIX_ . 'attribute_group_lang agl ON (ag.id_attribute_group = agl.id_attribute_group AND agl.id_lang = ' . (int) $defaultLangId . ')
                        WHERE pa.id_product = ' . (int) $product->id . '
                        ORDER BY ag.position, agl.name, a.position
                    ';

                    $attributesResult = Db::getInstance()->executeS($attributesQuery);

                    if ($attributesResult) {
                        // Process attribute groups and values
                        $processedGroups = [];
                        foreach ($attributesResult as $attr) {
                            // Process attribute option value
                            $optionValue = [
                                'id' => (int) $attr['id_attribute'],
                                'name' => $attr['attribute_name'],
                                'attribute_group' => $attr['group_name'],
                                'attribute_group_id' => (int) $attr['id_attribute_group'],
                                'position' => (int) $attr['position'],
                            ];

                            // Add color if it exists
                            if (!empty($attr['color'])) {
                                $optionValue['color'] = $attr['color'];
                            }

                            // Add to product option values array (avoid duplicates)
                            $found = false;
                            foreach ($productOptionValues as $existingOption) {
                                if ($existingOption['id'] === $optionValue['id']) {
                                    $found = true;
                                    break;
                                }
                            }

                            if (!$found) {
                                $productOptionValues[] = $optionValue;
                            }

                            // Process attribute groups (avoid duplicates)
                            if (!isset($processedGroups[$attr['id_attribute_group']])) {
                                $attributeGroups[] = [
                                    'id' => (int) $attr['id_attribute_group'],
                                    'name' => $attr['group_name'],
                                    'public_name' => $attr['group_public_name'],
                                    'position' => (int) $attr['group_position'],
                                ];
                                $processedGroups[$attr['id_attribute_group']] = true;
                            }
                        }
                    }

                    // If DB approach didn't work, try API approach
                    if (empty($productOptionValues)) {
                        $attributes = [];
                        try {
                            $attributes = $product->getAttributesResume($defaultLangId);
                        } catch (Exception $e) {
                            PrestaShopLogger::addLog(
                                sprintf('[ChatDataWebhook] Error getting product attributes resume: %s', $e->getMessage()),
                                3, // Severity: 3 for error
                                null,
                                'ChatDataWebhook',
                                null,
                                true
                            );
                        }

                        if (!empty($attributes)) {
                            $attributesIds = [];
                            foreach ($attributes as $attribute) {
                                $attributesIds[$attribute['id_attribute_group']][] = $attribute['id_attribute'];
                            }

                            foreach ($attributesIds as $idGroup => $idAttributes) {
                                try {
                                    // Different PrestaShop versions have different constructor signatures
                                    $group = new AttributeGroup($idGroup);
                                    $groupName = isset($group->name[$defaultLangId]) ? $group->name[$defaultLangId] : ($group->name ?? 'Group ' . $idGroup);
                                    $groupPublicName = isset($group->public_name[$defaultLangId]) ? $group->public_name[$defaultLangId] : $groupName;

                                    // Add group
                                    $attributeGroups[] = [
                                        'id' => (int) $idGroup,
                                        'name' => $groupName,
                                        'public_name' => $groupPublicName,
                                        'position' => (int) $group->position,
                                    ];

                                    foreach ($idAttributes as $idAttribute) {
                                        // Different PrestaShop versions have different constructor signatures
                                        // Older versions only accept ID parameter
                                        try {
                                            $attribute = new Attribute($idAttribute);
                                            $attributeName = isset($attribute->name[$defaultLangId]) ? $attribute->name[$defaultLangId] : ($attribute->name ?? 'Attribute ' . $idAttribute);

                                            $optionValue = [
                                                'id' => (int) $idAttribute,
                                                'name' => $attributeName,
                                                'attribute_group' => $groupName,
                                                'attribute_group_id' => (int) $idGroup,
                                                'position' => (int) $attribute->position,
                                            ];

                                            // Add color if it exists
                                            if (!empty($attribute->color)) {
                                                $optionValue['color'] = $attribute->color;
                                            }

                                            $productOptionValues[] = $optionValue;
                                        } catch (Exception $e) {
                                            PrestaShopLogger::addLog(
                                                sprintf('[ChatDataWebhook] Error getting attribute details: %s', $e->getMessage()),
                                                3, // Severity: 3 for error
                                                null,
                                                'ChatDataWebhook',
                                                null,
                                                true
                                            );
                                        }
                                    }
                                } catch (Exception $e) {
                                    PrestaShopLogger::addLog(
                                        sprintf('[ChatDataWebhook] Error getting attribute group details: %s', $e->getMessage()),
                                        3, // Severity: 3 for error
                                        null,
                                        'ChatDataWebhook',
                                        null,
                                        true
                                    );
                                }
                            }
                        }
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product option values: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }

                // Get combinations
                $combinationsList = [];
                try {
                    $combinationsList = $product->getAttributeCombinations($defaultLangId);
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product combinations: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }

                // Get all combination details through DB for maximum data
                $combinationsDetails = [];
                try {
                    $combinationsDetailsQuery = '
                        SELECT 
                            pa.*, 
                            sa.quantity,
                            GROUP_CONCAT(pac.id_attribute) as attributes
                        FROM ' . _DB_PREFIX_ . 'product_attribute pa
                        LEFT JOIN ' . _DB_PREFIX_ . 'stock_available sa ON (pa.id_product_attribute = sa.id_product_attribute AND sa.id_product = pa.id_product)
                        LEFT JOIN ' . _DB_PREFIX_ . 'product_attribute_combination pac ON (pa.id_product_attribute = pac.id_product_attribute)
                        WHERE pa.id_product = ' . (int) $product->id . '
                        GROUP BY pa.id_product_attribute
                    ';
                    $combinationsDetailsResult = Db::getInstance()->executeS($combinationsDetailsQuery);
                    if ($combinationsDetailsResult) {
                        foreach ($combinationsDetailsResult as $comboDetails) {
                            $combinationsDetails[$comboDetails['id_product_attribute']] = $comboDetails;
                        }
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting combinations details: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }

                $processedCombinations = [];

                foreach ($combinationsList as $combo) {
                    $idCombination = $combo['id_product_attribute'];

                    if (!isset($processedCombinations[$idCombination])) {
                        // Create base combination data
                        $basePrice = (float) $product->price + (float) $combo['price'];

                        $detailedCombo = [
                            'id' => $idCombination,
                            'reference' => !empty($combo['reference']) ? $combo['reference'] : $product->reference,
                            'quantity' => isset($combinationsDetails[$idCombination]['quantity']) ? (int) $combinationsDetails[$idCombination]['quantity'] : StockAvailable::getQuantityAvailableByProduct($product->id, $idCombination),
                            'options' => [],
                        ];

                        // Add EAN13, ISBN, UPC if available in combinations detail
                        if (isset($combinationsDetails[$idCombination])) {
                            if (!empty($combinationsDetails[$idCombination]['ean13'])) {
                                $detailedCombo['ean13'] = $combinationsDetails[$idCombination]['ean13'];
                            }
                            if (!empty($combinationsDetails[$idCombination]['isbn'])) {
                                $detailedCombo['isbn'] = $combinationsDetails[$idCombination]['isbn'];
                            }
                            if (!empty($combinationsDetails[$idCombination]['upc'])) {
                                $detailedCombo['upc'] = $combinationsDetails[$idCombination]['upc'];
                            }
                            if (!empty($combinationsDetails[$idCombination]['mpn'])) {
                                $detailedCombo['mpn'] = $combinationsDetails[$idCombination]['mpn'];
                            }

                            // Add weight
                            $combinationWeight = (float) $combinationsDetails[$idCombination]['weight'];
                            if ($combinationWeight != 0) {
                                $totalWeight = $combinationWeight + (float) $product->weight;
                                $detailedCombo['weight'] = $totalWeight . ' ' . $weightUnit;
                            }
                        }

                        // Check for specific prices for this combination following JavaScript logic
                        $combinationSpecificPrice = null;
                        $applicableSpecificPrices = [];

                        // Filter specific prices that apply to this combination (id_product_attribute = 0 or matches combination ID)
                        foreach ($filteredSpecificPrices as $sp) {
                            if ($sp['id_product_attribute'] == '0' || (string) $sp['id_product_attribute'] === (string) $idCombination) {
                                $applicableSpecificPrices[] = $sp;
                            }
                        }

                        if (!empty($applicableSpecificPrices)) {
                            // Sort by date to get the most recent applicable price (like JavaScript)
                            usort($applicableSpecificPrices, function ($a, $b) {
                                $dateA = ($a['from'] !== '0000-00-00 00:00:00') ? strtotime($a['from']) : 0;
                                $dateB = ($b['from'] !== '0000-00-00 00:00:00') ? strtotime($b['from']) : 0;

                                return $dateB - $dateA; // Sort descending (most recent first)
                            });

                            $sp = $applicableSpecificPrices[0]; // Get the most recent
                            $finalPrice = $basePrice;

                            // Calculate final price based on reduction type
                            if ($sp['reduction_type'] == 'amount') {
                                $finalPrice = $basePrice - (float) $sp['reduction'];
                            } elseif ($sp['reduction_type'] == 'percentage') {
                                $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                            }

                            // Format discount amount
                            $discountAmount = '';
                            if ($sp['reduction_type'] == 'amount') {
                                $discountAmount = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                            } else {
                                $discountAmount = (float) ($sp['reduction'] * 100) . '%';
                            }

                            $combinationSpecificPrice = [
                                'regular_price_before_tax_shipping' => Tools::displayPrice($basePrice, $defaultCurrencyId),
                                'sale_price_before_tax_shipping' => Tools::displayPrice($finalPrice, $defaultCurrencyId),
                                'discount_type' => $sp['reduction_type'],
                                'discount_amount' => $discountAmount,
                                'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                                'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                            ];
                        }

                        // Add price field based on special price availability
                        if (!$combinationSpecificPrice) {
                            $detailedCombo['price_before_tax_shipping'] = Tools::displayPrice($basePrice, $defaultCurrencyId);
                        } else {
                            $detailedCombo['special_price'] = $combinationSpecificPrice;
                        }

                        $processedCombinations[$idCombination] = $detailedCombo;
                    }

                    // Add this attribute to the combination's options
                    $attributeId = (int) $combo['id_attribute'];

                    // Find detailed option from product_option_values
                    $foundOption = null;
                    foreach ($productOptionValues as $optionValue) {
                        if ($optionValue['id'] === $attributeId) {
                            $foundOption = $optionValue;
                            break;
                        }
                    }

                    // If not found, create a basic option
                    if (!$foundOption) {
                        $foundOption = [
                            'id' => $attributeId,
                            'name' => $combo['attribute_name'] ?? ('Option ' . $attributeId),
                        ];
                    }

                    // Add to combination options (if not already present)
                    $optionAlreadyAdded = false;
                    foreach ($processedCombinations[$idCombination]['options'] as $existingOption) {
                        if ($existingOption['id'] === $foundOption['id']) {
                            $optionAlreadyAdded = true;
                            break;
                        }
                    }

                    if (!$optionAlreadyAdded) {
                        $processedCombinations[$idCombination]['options'][] = $foundOption;
                    }
                }

                $combinations = array_values($processedCombinations);
            }

            // Get stock
            $stock = [];
            if (!empty($combinations)) {
                // If product has combinations, only include combination stocks (skip main product stock)
                foreach ($combinations as $combination) {
                    $comboStock = StockAvailable::getQuantityAvailableByProduct($product->id, $combination['id']);
                    $variantInfo = [
                        'id' => (string) $combination['id'],
                        'reference' => $combination['reference'],
                        'options' => $combination['options'],
                    ];

                    $stock[] = [
                        'quantity' => (string) $comboStock,
                        'variant' => $variantInfo,
                    ];
                }
            } else {
                // For simple products without combinations, keep single product stock
                $mainStock = StockAvailable::getQuantityAvailableByProduct($product->id);
                $stock[] = [
                    'quantity' => (string) $mainStock,
                    'variant' => 'Main product',
                ];
            }

            // Calculate total quantity as sum of all stocks
            $totalQuantity = 0;
            foreach ($stock as $stockItem) {
                $totalQuantity += (int) $stockItem['quantity'];
            }

            // Get product images
            $images = [];
            $productImages = $product->getImages($defaultLangId);
            if (!empty($productImages)) {
                foreach ($productImages as $image) {
                    $imageUrl = $context->link->getImageLink($linkRewrite, $product->id . '-' . $image['id_image']);
                    $images[] = [
                        'src' => $imageUrl,
                        'alt' => $productName,
                    ];
                }
            }

            // Get short and full description
            $shortDescription = '';
            if (is_array($product->description_short) && isset($product->description_short[$defaultLangId])) {
                $shortDescription = $product->description_short[$defaultLangId];
            } elseif (!is_array($product->description_short)) {
                $shortDescription = $product->description_short;
            }

            $fullDescription = '';
            if (is_array($product->description) && isset($product->description[$defaultLangId])) {
                $fullDescription = $product->description[$defaultLangId];
            } elseif (!is_array($product->description)) {
                $fullDescription = $product->description;
            }

            // Create detailed product info
            $productDetails = [
                'id' => $product->id,
                'title' => $productName,
            ];

            // Only add non-empty fields
            if (!empty($product->reference)) {
                $productDetails['reference'] = $product->reference;
            }

            if (!empty($linkRewrite)) {
                $productDetails['link'] = $context->link->getProductLink($product->id, $linkRewrite, null, null, $defaultLangId);
            }

            $productDetails['status'] = (bool) $product->active ? 'active' : 'inactive';

            if (!empty($manufacturerName)) {
                $productDetails['manufacturer'] = $manufacturerName;
            }

            if ($product->weight > 0) {
                $productDetails['weight'] = $product->weight . ' ' . $weightUnit;
            }

            // Add dimensions if any dimension exists
            if ((float) $product->width > 0 || (float) $product->height > 0 || (float) $product->depth > 0) {
                $productDetails['dimensions'] = [
                    'width' => (float) $product->width > 0 ? $product->width . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                    'height' => (float) $product->height > 0 ? $product->height . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                    'depth' => (float) $product->depth > 0 ? $product->depth . ' ' . $dimensionUnit : '0 ' . $dimensionUnit,
                ];
            }

            if (!empty($product->condition)) {
                $productDetails['condition'] = $product->condition;
            }

            $productDetails['quantity'] = $totalQuantity;

            // Add unit pricing information if it exists
            if (!empty($product->unity)) {
                $unitPricing = [
                    'unit' => $product->unity,
                ];

                // Add unit price if greater than 0
                if ((float) $product->unit_price > 0) {
                    $unitPricing['unit_price'] = Tools::displayPrice((float) $product->unit_price, $defaultCurrencyId);
                }

                // Add ratio if it exists
                if (!empty($product->unit_price_ratio)) {
                    $unitPricing['ratio'] = (string) $product->unit_price_ratio;
                }

                $productDetails['unit_pricing'] = $unitPricing;
            }

            // Add shipping information if additional cost exists
            if ((float) $product->additional_shipping_cost > 0) {
                $productDetails['additional_shipping_cost'] = Tools::displayPrice((float) $product->additional_shipping_cost, $defaultCurrencyId);
            }

            // Add product identifiers if they exist and aren't empty
            if (!empty($product->ean13)) {
                $productDetails['ean13'] = $product->ean13;
            }

            if (!empty($product->isbn)) {
                $productDetails['isbn'] = $product->isbn;
            }

            if (!empty($product->upc)) {
                $productDetails['upc'] = $product->upc;
            }

            if (!empty($product->mpn)) {
                $productDetails['mpn'] = $product->mpn;
            }

            if (!empty($categories)) {
                $productDetails['categories'] = $categories;
            }

            if (!empty($categoryPaths)) {
                $productDetails['category_paths'] = $categoryPaths;
            }

            // Add default category if available
            if (!empty($defaultCategory)) {
                $productDetails['default_category'] = $defaultCategory;
            }

            if (!empty($features)) {
                $productDetails['features'] = $features;
            }

            if (!empty($accessories)) {
                $productDetails['accessories'] = $accessories;
            }

            // Only add attribute groups if they contain data
            if (is_array($attributeGroups) && count($attributeGroups) > 0) {
                $productDetails['options'] = $attributeGroups;
            }

            // Only add product option values if they contain data
            if (is_array($productOptionValues) && count($productOptionValues) > 0) {
                $productDetails['product_option_values'] = $productOptionValues;
            }

            if (!empty($combinations)) {
                $productDetails['combinations'] = $combinations;
            }

            // Add stock details (combinations stocks if available, or main product stock)
            if (is_array($stock) && count($stock) > 0) {
                $productDetails['stock'] = $stock;
            }

            if (!empty($product->date_add)) {
                $productDetails['date_add'] = $product->date_add;
            }

            if (!empty($product->date_upd)) {
                $productDetails['date_upd'] = $product->date_upd;
            }

            if ((int) $product->minimal_quantity > 1) {
                $productDetails['minimal_quantity'] = (string) $product->minimal_quantity;
            }

            $productDetails['type'] = $hasAttributes ? 'combinations' : 'simple';

            if (!empty($images)) {
                $productDetails['images'] = $images;
            }

            if (!empty($shortDescription)) {
                $productDetails['short_description'] = $shortDescription;
            }

            if (!empty($fullDescription)) {
                $productDetails['description'] = $fullDescription;
            }

            // Add meta fields if they exist and are non-empty
            $metaTitle = '';
            if (is_array($product->meta_title) && isset($product->meta_title[$defaultLangId])) {
                $metaTitle = $product->meta_title[$defaultLangId];
            } elseif (!is_array($product->meta_title)) {
                $metaTitle = $product->meta_title;
            }
            if (!empty($metaTitle)) {
                $productDetails['meta_title'] = $metaTitle;
            }

            $metaKeywords = '';
            if (is_array($product->meta_keywords) && isset($product->meta_keywords[$defaultLangId])) {
                $metaKeywords = $product->meta_keywords[$defaultLangId];
            } elseif (!is_array($product->meta_keywords)) {
                $metaKeywords = $product->meta_keywords;
            }
            if (!empty($metaKeywords)) {
                $productDetails['meta_keywords'] = $metaKeywords;
            }

            $metaDescription = '';
            if (is_array($product->meta_description) && isset($product->meta_description[$defaultLangId])) {
                $metaDescription = $product->meta_description[$defaultLangId];
            } elseif (!is_array($product->meta_description)) {
                $metaDescription = $product->meta_description;
            }
            if (!empty($metaDescription)) {
                $productDetails['meta_description'] = $metaDescription;
            }

            // Add delivery fields if they exist and are non-empty
            $deliveryInStock = '';
            if (is_array($product->delivery_in_stock) && isset($product->delivery_in_stock[$defaultLangId])) {
                $deliveryInStock = $product->delivery_in_stock[$defaultLangId];
            } elseif (!is_array($product->delivery_in_stock)) {
                $deliveryInStock = $product->delivery_in_stock;
            }
            if (!empty($deliveryInStock)) {
                $productDetails['delivery_in_stock'] = $deliveryInStock;
            }

            $deliveryOutStock = '';
            if (is_array($product->delivery_out_stock) && isset($product->delivery_out_stock[$defaultLangId])) {
                $deliveryOutStock = $product->delivery_out_stock[$defaultLangId];
            } elseif (!is_array($product->delivery_out_stock)) {
                $deliveryOutStock = $product->delivery_out_stock;
            }
            if (!empty($deliveryOutStock)) {
                $productDetails['delivery_out_stock'] = $deliveryOutStock;
            }

            $availableLater = '';
            if (is_array($product->available_later) && isset($product->available_later[$defaultLangId])) {
                $availableLater = $product->available_later[$defaultLangId];
            } elseif (!is_array($product->available_later)) {
                $availableLater = $product->available_later;
            }
            if (!empty($availableLater)) {
                $productDetails['available_later'] = $availableLater;
            }

            $availableNow = '';
            if (is_array($product->available_now) && isset($product->available_now[$defaultLangId])) {
                $availableNow = $product->available_now[$defaultLangId];
            } elseif (!is_array($product->available_now)) {
                $availableNow = $product->available_now;
            }
            if (!empty($availableNow)) {
                $productDetails['available_now'] = $availableNow;
            }

            // Set flags based on binary values (following JavaScript logic)
            if ($product->on_sale === '1') {
                $productDetails['on_sale'] = true;
            }
            if ($product->customizable === '1') {
                $productDetails['customizable'] = true;
            }
            if ($product->online_only === '1') {
                $productDetails['online_only'] = true;
            }
            if ($product->is_virtual === '1') {
                $productDetails['is_virtual'] = true;
            }
            if ($product->available_for_order === '1') {
                $productDetails['available_for_order'] = true;
            }
            if ($product->show_price === '1') {
                $productDetails['show_price'] = true;
            }

            // Add product type if available (PS 1.7.7+)
            if (method_exists($product, 'getProductType')) {
                try {
                    $productType = $product->getProductType();
                    if (!empty($productType)) {
                        $productDetails['product_type'] = $productType;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product type: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            if (!empty($tags)) {
                $productDetails['tags'] = $tags;
            }

            // Add pricing information for the main product
            if (!$hasAttributes) {
                // For simple products without combinations, apply the same pricing logic as combinations
                $basePrice = (float) $product->price;
                $mainProductSpecificPrice = null;

                // Filter specific prices that apply to the main product (id_product_attribute = 0)
                $applicableMainSpecificPrices = [];
                foreach ($filteredSpecificPrices as $sp) {
                    if ($sp['id_product_attribute'] == '0') {
                        $applicableMainSpecificPrices[] = $sp;
                    }
                }

                if (!empty($applicableMainSpecificPrices)) {
                    // Sort by date to get the most recent applicable price
                    usort($applicableMainSpecificPrices, function ($a, $b) {
                        $dateA = ($a['from'] !== '0000-00-00 00:00:00') ? strtotime($a['from']) : 0;
                        $dateB = ($b['from'] !== '0000-00-00 00:00:00') ? strtotime($b['from']) : 0;

                        return $dateB - $dateA; // Sort descending (most recent first)
                    });

                    $sp = $applicableMainSpecificPrices[0]; // Get the most recent
                    $finalPrice = $basePrice;

                    // Calculate final price based on reduction type
                    if ($sp['reduction_type'] == 'amount') {
                        $finalPrice = $basePrice - (float) $sp['reduction'];
                    } elseif ($sp['reduction_type'] == 'percentage') {
                        $finalPrice = $basePrice * (1 - (float) $sp['reduction']);
                    }

                    // Format discount amount
                    $discountAmount = '';
                    if ($sp['reduction_type'] == 'amount') {
                        $discountAmount = Tools::displayPrice((float) $sp['reduction'], $defaultCurrencyId);
                    } else {
                        $discountAmount = (float) ($sp['reduction'] * 100) . '%';
                    }

                    $mainProductSpecificPrice = [
                        'regular_price_before_tax_shipping' => Tools::displayPrice($basePrice, $defaultCurrencyId),
                        'sale_price_before_tax_shipping' => Tools::displayPrice($finalPrice, $defaultCurrencyId),
                        'discount_type' => $sp['reduction_type'],
                        'discount_amount' => $discountAmount,
                        'from_date' => $sp['from'] == '0000-00-00 00:00:00' ? 'Always' : date('Y-m-d', strtotime($sp['from'])),
                        'to_date' => $sp['to'] == '0000-00-00 00:00:00' ? 'No end date' : date('Y-m-d', strtotime($sp['to'])),
                    ];
                }

                // Add price field based on special price availability
                if (!$mainProductSpecificPrice) {
                    $productDetails['price_before_tax_shipping'] = Tools::displayPrice($basePrice, $defaultCurrencyId);
                } else {
                    $productDetails['special_price'] = $mainProductSpecificPrice;
                }
            }

            // Add product type if available (PS 1.7.7+)
            if (method_exists($product, 'getProductType')) {
                try {
                    $productType = $product->getProductType();
                    if (!empty($productType)) {
                        $productDetails['product_type'] = $productType;
                    }
                } catch (Exception $e) {
                    PrestaShopLogger::addLog(
                        sprintf('[ChatDataWebhook] Error getting product type: %s', $e->getMessage()),
                        3, // Severity: 3 for error
                        null,
                        'ChatDataWebhook',
                        null,
                        true
                    );
                }
            }

            if (!empty($tags)) {
                $productDetails['tags'] = $tags;
            }
        }

        $jsonData = json_encode($productDetails);

        // Using cURL to send the POST request
        $ch = curl_init($targetUrl);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Content-Length: ' . strlen($jsonData),
            'X-PrestaShop-Webhook-Signature: ' . base64_encode(hash_hmac('sha256', $jsonData, $secret, true)),
            'X-PrestaShop-Webhook-Topic: ' . $eventType,
            'X-PrestaShop-Shop-Url: ' . _PS_BASE_URL_,
            'X-PrestaShop-Timestamp: ' . date('c'),
            'X-PrestaShop-Test-Mode: true',
        ]);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);

        $result = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $curlError = curl_error($ch);
        curl_close($ch);

        // Log the attempt
        if ($result === false || $httpCode >= 400) {
            PrestaShopLogger::addLog(
                sprintf('[ChatDataWebhook] Failed to send webhook. Event: %s, URL: %s, HTTP Code: %s, cURL Error: %s', $eventType, $targetUrl, $httpCode, $curlError),
                3, // Severity: 3 for error
                null,
                'ChatDataWebhook',
                null,
                true
            );
        } else {
            PrestaShopLogger::addLog(
                sprintf('[ChatDataWebhook] Webhook sent successfully. Event: %s, URL: %s, HTTP Code: %s', $eventType, $targetUrl, $httpCode),
                1, // Severity: 1 for informational
                null,
                'ChatDataWebhook',
                null,
                true
            );
        }

        if ($result === false) {
            return [
                'success' => false,
                'error' => $curlError,
                'http_code' => $httpCode,
            ];
        } elseif ($httpCode >= 400) {
            return [
                'success' => false,
                'error' => 'HTTP Error ' . $httpCode,
                'http_code' => $httpCode,
                'response' => $result,
            ];
        } else {
            return [
                'success' => true,
                'http_code' => $httpCode,
                'response' => $result,
            ];
        }
    }
}
